@@ -167,7 +167,7 @@ class FAAPI:
         submissions: list[SubmissionPartial] = [SubmissionPartial(f) for f in parse_submission_figures(page_parsed)]
         return sorted({s for s in submissions}, reverse=True)
 
-    def submission(self, submission_id: int, get_file: bool = False, *, chunk_size: int = None
+    def submission(self, submission_id: int, get_file: bool = False, *, chunk_size: Optional[int] = None
                    ) -> tuple[Submission, Optional[bytes]]:
         """
         Fetch a submission and, optionally, its file.
@@ -181,7 +181,7 @@ class FAAPI:
         sub_file: Optional[bytes] = self.submission_file(sub, chunk_size=chunk_size) if get_file and sub.id else None
         return sub, sub_file
 
-    def submission_file(self, submission: Submission, *, chunk_size: int = None) -> bytes:
+    def submission_file(self, submission: Submission, *, chunk_size: Optional[int] = None) -> bytes:
         """
         Fetch a submission file from a Submission object.
 
@@ -222,10 +222,10 @@ class FAAPI:
         page_parsed: BeautifulSoup = self.get_parsed(join_url("gallery", quote(username_url(user)), int(page)))
         info_parsed: dict[str, Any] = parse_user_submissions(page_parsed)
         author: UserPartial = UserPartial()
-        author.name, author.status, author.title, author.join_date, author.user_icon_url = [
-            info_parsed["user_name"], info_parsed["user_status"],
-            info_parsed["user_title"], info_parsed["user_join_date"],
-            info_parsed["user_icon_url"]
+        author.name, author.status, author.title, author.join_date, author.avatar_url = [
+            info_parsed["name"], info_parsed["status"],
+            info_parsed["title"], info_parsed["join_date"],
+            info_parsed["avatar_url"]
         ]
         for s in (submissions := list(map(SubmissionPartial, info_parsed["figures"]))):
             s.author = author
@@ -243,10 +243,10 @@ class FAAPI:
         page_parsed: BeautifulSoup = self.get_parsed(join_url("scraps", quote(username_url(user)), int(page)))
         info_parsed: dict[str, Any] = parse_user_submissions(page_parsed)
         author: UserPartial = UserPartial()
-        author.name, author.status, author.title, author.join_date, author.user_icon_url = [
-            info_parsed["user_name"], info_parsed["user_status"],
-            info_parsed["user_title"], info_parsed["user_join_date"],
-            info_parsed["user_icon_url"]
+        author.name, author.status, author.title, author.join_date, author.avatar_url = [
+            info_parsed["name"], info_parsed["status"],
+            info_parsed["title"], info_parsed["join_date"],
+            info_parsed["avatar_url"]
         ]
         for s in (submissions := list(map(SubmissionPartial, info_parsed["figures"]))):
             s.author = author
@@ -276,10 +276,10 @@ class FAAPI:
         page_parsed: BeautifulSoup = self.get_parsed(join_url("journals", quote(username_url(user)), int(page)))
         info_parsed: dict[str, Any] = parse_user_journals(page_parsed)
         author: UserPartial = UserPartial()
-        author.name, author.status, author.title, author.join_date, author.user_icon_url = [
-            info_parsed["user_name"], info_parsed["user_status"],
-            info_parsed["user_title"], info_parsed["user_join_date"],
-            info_parsed["user_icon_url"]
+        author.name, author.status, author.title, author.join_date, author.avatar_url = [
+            info_parsed["name"], info_parsed["status"],
+            info_parsed["title"], info_parsed["join_date"],
+            info_parsed["avatar_url"]
         ]
         for j in (journals := list(map(JournalPartial, info_parsed["sections"]))):
             j.author = author
