@@ -15,7 +15,8 @@ class Comment:
     Contains comment information and references to replies and parent objects.
     """
 
-    def __init__(self, tag: Tag = None, parent: Union[faapi.submission.Submission, faapi.journal.Journal] = None):
+    def __init__(self, tag: Optional[Tag] = None,
+                 parent: Optional[Union[faapi.submission.Submission, faapi.journal.Journal]] = None):
         """
         :param tag: The comment tag from which to parse information
         :param parent: The parent object of the comment
@@ -110,7 +111,7 @@ class Comment:
         """
         return "" if self.parent is None else f"{self.parent.url}#cid:{self.id}"
 
-    def parse(self, comment_tag: Tag = None):
+    def parse(self, comment_tag: Optional[Tag] = None):
         """
         Parse a comment tag, overrides any information already present in the object.
 
@@ -130,7 +131,7 @@ class Comment:
         self.author = faapi.user.UserPartial()
         self.author.name = parsed["user_name"]
         self.author.title = parsed["user_title"]
-        self.author.user_icon_url = parsed["user_icon_url"]
+        self.author.avatar_url = parsed["avatar_url"]
         self.text = parsed["text"]
         self.replies = []
         self.reply_to = parsed["parent"]
