@@ -110,7 +110,7 @@ class JournalPartial(JournalBase):
     Contains partial journal information gathered from journals pages.
     """
 
-    def __init__(self, journal_tag: Tag = None):
+    def __init__(self, journal_tag: Optional[Tag] = None):
         """
         :param journal_tag: The tag from which to parse the journal.
         """
@@ -122,7 +122,7 @@ class JournalPartial(JournalBase):
 
         self.parse()
 
-    def parse(self, journal_tag: Union[Tag, BeautifulSoup] = None):
+    def parse(self, journal_tag: Optional[Union[Tag, BeautifulSoup]] = None):
         """
         Parse a journal tag, overrides any information already present in the object.
 
@@ -144,7 +144,7 @@ class JournalPartial(JournalBase):
         self.author.status = parsed.get("user_status", "")
         self.author.title = parsed.get("user_title", "")
         self.author.join_date = parsed.get("user_join_date", "")
-        self.author.user_icon_url = parsed.get("user_icon_url", "")
+        self.author.avatar_url = parsed.get("avatar_url", "")
         self.stats = JournalStats(parsed["comments"])
         self.date = parsed["date"]
         self.content = parsed["content"]
@@ -156,7 +156,7 @@ class Journal(JournalBase):
     Contains complete journal information gathered from journal pages, including comments.
     """
 
-    def __init__(self, journal_page: BeautifulSoup = None):
+    def __init__(self, journal_page: Optional[BeautifulSoup] = None):
         """
         :param journal_page: The page from which to parse the journal.
         """
@@ -199,7 +199,7 @@ class Journal(JournalBase):
         """
         return html_to_bbcode(self.footer)
 
-    def parse(self, journal_page: Union[Tag, BeautifulSoup] = None):
+    def parse(self, journal_page: Optional[Union[Tag, BeautifulSoup]] = None):
         """
         Parse a journal page, overrides any information already present in the object.
 
@@ -219,11 +219,11 @@ class Journal(JournalBase):
         # noinspection DuplicatedCode
         self.id = parsed["id"]
         self.title = parsed["title"]
-        self.author.name = parsed.get("user_name", "")
-        self.author.status = parsed.get("user_status", "")
-        self.author.title = parsed.get("user_title", "")
-        self.author.join_date = parsed.get("user_join_date", "")
-        self.author.user_icon_url = parsed.get("user_icon_url", "")
+        self.author.name = parsed["user_info"]["name"]
+        self.author.status = parsed["user_info"]["status"]
+        self.author.title = parsed["user_info"]["title"]
+        self.author.join_date = parsed["user_info"]["join_date"]
+        self.author.avatar_url = parsed["user_info"]["avatar_url"]
         self.stats = JournalStats(parsed["comments"])
         self.date = parsed["date"]
         self.content = parsed["content"]
